@@ -1,4 +1,4 @@
-/* $Cambridge: hermes/src/prayer/cmd/cmd_exit.c,v 1.3 2008/09/16 09:59:55 dpc22 Exp $ */
+/* $Cambridge: hermes/src/prayer/cmd/cmd_exit.c,v 1.4 2010/07/02 14:32:06 dpc22 Exp $ */
 /************************************************
  *    Prayer - a Webmail Interface              *
  ************************************************/
@@ -56,21 +56,5 @@ void cmd_exit(struct session *session)
     if (user_agent->use_debug)
         url = pool_strcat(request->pool, url, "/debug");
 
-    if (session->use_cookie && config->http_cookie_use_port) {
-        char *path =
-            pool_strcat(request->pool, "/session/", session->username);
-        char *key;
-
-        if (config->http_cookie_use_port)
-            key = pool_printf(request->pool, "%s:%lu",
-                              session->username, session->session_port);
-        else
-            key = session->username;
-
-        response_clear_cookie_redirect(request, url,
-                                       key, session->sessionid,
-                                       path, config->hostname,
-				       session->use_ssl);
-    } else
-        response_redirect(request, url);
+    response_redirect(request, url);
 }
