@@ -1,4 +1,4 @@
-/* $Cambridge: hermes/src/prayer/cmd/cmd_restart.c,v 1.4 2008/09/17 17:20:25 dpc22 Exp $ */
+/* $Cambridge: hermes/src/prayer/cmd/cmd_restart.c,v 1.5 2011/01/11 13:24:30 dpc22 Exp $ */
 /************************************************
  *    Prayer - a Webmail Interface              *
  ************************************************/
@@ -97,7 +97,7 @@ void cmd_restart(struct session *session)
             }
         }
 
-        if (!(stream = ml_open(session, NIL, s, 0))) {
+        if (!stream) {
             session_alert(session, ("Unable to reestablish connection"
                                     " with IMAP server "));
             generate_error_page(session);
