@@ -1,4 +1,4 @@
-/* $Cambridge: hermes/src/prayer/lib/mystring.c,v 1.2 2008/05/19 15:55:56 dpc22 Exp $ */
+/* $Cambridge: hermes/src/prayer/lib/mystring.c,v 1.4 2009/04/09 10:31:38 dpc22 Exp $ */
 /************************************************
  *    Prayer - a Webmail Interface              *
  ************************************************/
@@ -1037,62 +1037,6 @@ char *string_filename_encode(struct pool *pool, char *arg)
 
 /* ====================================================================== */
 
-/* string_date_to_string_short() *****************************************
- *
- * Convert (month, day) tuple into printable form.
- *   month: month in range 1 to 12
- *     day: Day in range 1 to 31
- *
- * Returns: Date in printable form
- ***********************************************************************/
-
-char *string_date_to_string_short(unsigned long month, unsigned long day)
-{
-    static char *date_month[12] = {
-        "Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep",
-        "Oct",
-        "Nov", "Dec"
-    };
-    static char result[64];
-
-    if ((month < 1) || (month > 12))
-        return ("");
-
-    sprintf(result, "%s %lu", date_month[month - 1], day);
-
-    return (result);
-}
-
-/* string_date_to_string_long() *****************************************
- *
- * Convert (month, day, year) tuple into printable form.
- *   month: month in range 1 to 12
- *     day: Day in range 1 to 31
- *    year: Four digit date.
- *
- * Returns: Date in printable form
- ***********************************************************************/
-
-char *string_date_to_string_long(unsigned long month,
-                                 unsigned long day, unsigned long year)
-{
-    static char *date_month[12] = {
-        "Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep",
-        "Oct",
-        "Nov", "Dec"
-    };
-    static char result[64];
-
-    if ((month < 1) || (month > 12))
-        return ("");
-
-    sprintf(result, "%s %lu %lu", date_month[month - 1], day, year);
-
-    return (result);
-}
-
-/* ====================================================================== */
-
 /* Small malloc interface library */
 
 /* string_malloc() ******************************************************
@@ -1189,6 +1133,27 @@ char *string_lcase (char *s)
 
 /* ====================================================================== */
 
+/* string_has8bit() *******************************************************
+ *
+ * Does string contain 8 bit characters.
+ *
+ **************************************************************************/
+
+BOOL string_has8bit(char *s0)
+{
+    unsigned char *s = (unsigned char *)s0;
+
+    if (!s)
+        return(NIL);
+
+    while (*s) {
+        if ((*s) & 0x80)
+            return(T);
+        s++;
+    }
+    return(NIL);
+}
+
 /* string_strip8bit() *****************************************************
  *
  * Strip all 8bit characters from string in place. Can cope with NIL input.
@@ -1274,8 +1239,6 @@ string_base64_decode(unsigned char *src,unsigned long srcl,unsigned long *len)
    JNK,JNK,JNK,JNK,JNK,JNK,JNK,JNK,JNK,JNK,JNK,JNK,JNK,JNK,JNK,JNK,
    JNK,JNK,JNK,JNK,JNK,JNK,JNK,JNK,JNK,JNK,JNK,JNK,JNK,JNK,JNK,JNK
   };
-				/* initialize block */
-  memset (ret,0,((size_t) *len) + 1);
   *len = 0;			/* in case we return an error */
 
 				/* simple-minded decode */
@@ -1465,3 +1428,55 @@ char *string_expand(struct pool *pool, struct assoc *h, char *s)
     }
     return (buffer_fetch(b, 0, buffer_size(b), NIL));
 }
+
+/* ====================================================================== */
+
+/* string_expand_crlf() ***************************************************
+ *
+ * Convert all CRLF, CR, LF sequences in a string into CRLF.
+ ************************************************************************/
+
+char *
+string_expand_crlf(struct pool *pool, char *s)
+{
+    struct buffer *b = buffer_create(pool, 64);
+
+    while (*s) {
+        if ((s[0] == '\015') && (s[1] == '\012')) {
+            bputs(b, ""CRLF);
+            s += 2;
+        } else if ((s[0] == '\015') || (s[0] == '\012')) {
+            bputs(b, ""CRLF);
+            s++;
+        } else {
+            bputc(b, *s);
+            s++;
+        }
+    }
+    return(buffer_fetch(b, 0, buffer_size(b), NIL));
+}
+
+/* string_string_crlf() **************************************************
+ *
+ * Replace all CRLF, CR, LF sequences in message with simple LF. Only
+ * suitable if target platform is Unix: better to ship as is, use
+ * string_expand_crlf on the way back for consistency.
+ ************************************************************************/
+
+void
+string_strip_crlf(char *s)
+{
+    char *d = s;
+
+    while (*s) {
+        if ((s[0] == '\015') && (s[1] == '\012')) {
+            *d++ = '\n';
+            s += 2;
+        } else if (d < s) {
+            *d++ = *s++;
+        } else {
+            s++; d++;
+        }
+    }
+    *d = '\0';
+}
