@@ -1,4 +1,4 @@
-/* $Cambridge: hermes/src/prayer/lib/os.c,v 1.5 2010/07/08 09:34:25 dpc22 Exp $ */
+/* $Cambridge: hermes/src/prayer/lib/os.c,v 1.8 2011/01/18 13:32:50 dpc22 Exp $ */
 /************************************************
  *    Prayer - a Webmail Interface              *
  ************************************************/
@@ -167,10 +167,8 @@ int os_bind_unix_socket(char *name)
 int *os_bind_inet_socket(unsigned long port, char *interface)
 {
     int optval, sockfd;
-    struct sockaddr_storage serv_addr;
     struct addrinfo *ai, *ai_list, ai_hints;
     char port_str[NI_MAXSERV];
-    socklen_t serv_addrlen;
     int j;
     int count = 0;
     int *results = NIL;
@@ -187,6 +185,7 @@ int *os_bind_inet_socket(unsigned long port, char *interface)
              interface);
         return(NIL);
     }
+
     count=0;
     for (ai=ai_list; ai; ai = ai->ai_next)
         count++;
@@ -200,7 +199,7 @@ int *os_bind_inet_socket(unsigned long port, char *interface)
 
     j=0;
     for (ai=ai_list; ai; ai=ai->ai_next) {
-        sockfd =  socket(ai->ai_family, ai->ai_socktype, ai->ai_protocol);
+        sockfd = socket(ai->ai_family, ai->ai_socktype, ai->ai_protocol);
 
         if (sockfd < 0) {
             log_panic("[os_bind_inet_socket()] socket() failed, %s",
@@ -210,19 +209,31 @@ int *os_bind_inet_socket(unsigned long port, char *interface)
 
         /* set reuseaddr, otherwise bind will fail after fast stop/start */
         optval = 1;
-        if (setsockopt
-            (sockfd, SOL_SOCKET, SO_REUSEADDR, (void *) &optval, sizeof(int))) {
+        if (setsockopt(sockfd, SOL_SOCKET, SO_REUSEADDR,
+                       (void *) &optval, sizeof(int))) {
             log_panic(("[os_bind_inet_socket()] setsockopt() failed: "
                        "couldn't set SO_REUSEADDR: %s"), strerror(errno));
             close(sockfd);
             return(NIL);
         }
-        
-        /* bind() as Internet domain socket */
-        memcpy(&serv_addr, ai->ai_addr, ai->ai_addrlen);
-        serv_addrlen = ai->ai_addrlen;
 
-        if (bind(sockfd, (struct sockaddr *) &serv_addr, serv_addrlen) < 0) {
+#ifdef IPV6_V6ONLY
+        if (ai->ai_family == AF_INET6) {
+            /* Linux refuses to bind to both '0.0.0.0' and '::' without
+               IPPROTO_IPV6. Alternative approach would be to reorder the
+               list so that '::' appears first and only try binding to
+               '0.0.0.0' if '::' fails. Exim daemon.c has long explanation.
+
+               IPPROTO_IPV6 is good enough for our needs on Hermes */
+
+            /* Ignore errors here */
+            optval = 1;
+            setsockopt(sockfd, IPPROTO_IPV6, IPV6_V6ONLY,
+                       (void *) &optval, sizeof(int));
+        }
+#endif
+
+        if (bind(sockfd, ai->ai_addr, ai->ai_addrlen) < 0) {
             log_panic("[os_bind_inet_socket()] bind() failed: %s",
                       strerror(errno));
             close(sockfd);
@@ -237,8 +248,9 @@ int *os_bind_inet_socket(unsigned long port, char *interface)
         }
         results[j++] = sockfd;
     }
+    results[j] = -1;
 
-    freeaddrinfo(ai);
+    freeaddrinfo(ai_list);
 
     return(results);
 }
