@@ -1,4 +1,4 @@
-/* $Cambridge: hermes/src/prayer/lib/ssl.c,v 1.5 2008/09/16 09:59:57 dpc22 Exp $ */
+/* $Cambridge: hermes/src/prayer/lib/ssl.c,v 1.6 2009/10/08 14:27:14 dpc22 Exp $ */
 /************************************************
  *    Prayer - a Webmail Interface              *
  ************************************************/
@@ -45,7 +45,7 @@ static BOOL ssl_verbose_logging = NIL;
 #define SSL_RSA_KEYLENGTH   (1024)
 
 /* Cipher list */
-#define SSLCIPHERLIST "ALL:!LOW"
+#define SSLCIPHERLIST "ALL:!ADH:RC4+RSA:+HIGH:+MEDIUM:+LOW:!SSLv2:!EXP"
 
 /* ====================================================================== */
 
@@ -392,6 +392,7 @@ void ssl_context_init(struct ssl_config *ssl_config)
     SSL_CTX_set_info_callback(client_ctx, info_callback);
 #ifdef SSL_MODE_AUTO_RETRY
     SSL_CTX_set_mode(client_ctx, SSL_MODE_AUTO_RETRY);
+#endif
 
     if (SSL_CTX_need_tmp_RSA(client_ctx))
         SSL_CTX_set_tmp_rsa_callback(client_ctx, rsa_callback);
@@ -404,7 +405,6 @@ void ssl_context_init(struct ssl_config *ssl_config)
     /* Set cipherlist */
     if (!SSL_CTX_set_cipher_list(client_ctx, SSLCIPHERLIST))
         log_fatal("SSL_CTX_set_cipher_list");
-#endif
 
     /* Set up server context */
     server_ctx = SSL_CTX_new(SSLv23_server_method());
@@ -418,6 +418,9 @@ void ssl_context_init(struct ssl_config *ssl_config)
                         SSL_OP_NETSCAPE_DEMO_CIPHER_CHANGE_BUG);
 #endif
 
+    /* SSLv2 now obsolete */
+    SSL_CTX_set_options(server_ctx, SSL_OP_NO_SSLv2);
+
     /* Start off with the session cache disabled */
     SSL_CTX_set_session_cache_mode(server_ctx, SSL_SESS_CACHE_OFF);
     SSL_CTX_sess_set_cache_size(server_ctx, 0);
@@ -542,6 +545,7 @@ void *ssl_start_server(int fd, unsigned long timeout)
     X509 *client_cert;
     char *ver;
     int bits;
+    int rc;
 
     if (!(ssl = SSL_new(server_ctx)))
         return (NIL);
@@ -586,18 +590,20 @@ void *ssl_start_server(int fd, unsigned long timeout)
         alarm(timeout);
     }
 
-    if (SSL_accept(ssl) <= 0) {
-        SSL_shutdown(ssl);
-        SSL_free(ssl);
-        ERR_remove_state(0);
-        return (NIL);
-    }
+    rc = SSL_accept(ssl);
 
     if (timeout > 0) {
         alarm(0);
         os_signal_alarm_clear();
     }
 
+    if (rc <= 0) {
+        SSL_shutdown(ssl);
+        SSL_free(ssl);
+        ERR_remove_state(0);
+        return (NIL);
+    }
+
     if ((client_cert = SSL_get_peer_certificate(ssl)))
         log_debug("SSL: Have client certificate");
     else
