@@ -1,4 +1,4 @@
-/* $Cambridge: hermes/src/prayer/lib/template_expand.c,v 1.3 2008/06/24 14:40:49 dpc22 Exp $ */
+/* $Cambridge: hermes/src/prayer/lib/template_expand.c,v 1.5 2008/09/16 09:59:57 dpc22 Exp $ */
 
 /************************************************
  *    Prayer - a Webmail Interface              *
@@ -82,10 +82,7 @@ template_expand_icon(struct template_vals_urlstate *urlstate,
 {
     unsigned char *s = (unsigned char *) t;
 
-    if (urlstate->use_short)
-        bprintf(b, "/icons/%s.gif", s);
-    else
-        bprintf(b, "%s/%s.gif", urlstate->url_prefix_icons, s);
+    bprintf(b, "%s/%s.gif", urlstate->url_prefix_icons, s);
 }
 
 /* ====================================================================== */
@@ -180,53 +177,31 @@ template_expand_var(char *s, struct str *str,
 }
 
 static char *
-template_expand_vars(struct str *str, char **sp,
+template_expand_vars(struct str *str, char *s,
                      struct template_expand_state *state)
 {
-    char *s = *sp;
     char *var;
     char varquote = 'n';
 
     /* Reuse single str variable */
     str_rewind(str, 0);
 
-    while (Uisspace(*s))
-        s++;
-
-    if (*s == '"') {
-        s++;
-        while (*s && (*s != '"')) {
-            if (*s != '$') {
-                str_putc(str, *s++);
-            } else if ((var = template_getvar(&s, &varquote, NIL))) {
-                template_expand_var(var, str, state, varquote);
-            } else
-                return(NIL);
-        }
-        if (*s == '"')
-            s++;
-    } else {
-        while (*s && !Uisspace(*s)) {
-            if (*s != '$') {
-                str_putc(str, *s++);
-            } else if ((var = template_getvar(&s, &varquote, NIL))) {
-                template_expand_var(var, str, state, varquote);
-            } else
-                return(NIL);
-        }
-
+    while (*s) {
+        if (*s != '$') {
+            str_putc(str, *s++);
+        } else if ((var = template_getvar(&s, &varquote, NIL))) {
+            template_expand_var(var, str, state, varquote);
+        } else
+            return(NIL);
     }
-    while (Uisspace(*s))
-        s++;
-    *sp = s;
     return(str_fetch(str));
 }
 
 static BOOL
 template_test_value(char *s, char *t, struct template_expand_state *state)
 {
-    char *val  = template_expand_vars(state->str2, &s, state);
-    char *val2 = template_expand_vars(state->str3, &t, state);
+    char *val  = template_expand_vars(state->str2, s, state);
+    char *val2 = template_expand_vars(state->str3, t, state);
 
     return((val && val2 && !strcmp(val, val2)) ? T : NIL);
 }
@@ -235,10 +210,13 @@ static void
 template_expand_vars_buffer(char *s, struct template_expand_state *state)
 {
     struct buffer *b = state->buffer;
-    char *value = template_expand_vars(state->str, &s, state);
+    char *value;
     char *var, *val1, *val2;
     char quoting = 'h';
 
+    value = template_getexpr(&s, state->pool);
+    value = template_expand_vars(state->str, value, state);
+
     if (!strncasecmp(s, "IFDEF", 5) && Uisspace(s[5])) {
         s += 6;
         if (!((var = template_getvar(&s, NIL, NIL)) &&
@@ -472,7 +450,8 @@ template_expand_call_add_param(struct assoc *params,
     if ((t = strstr(s, "=>"))) {
         *t = '\0';
         t += 2;
-        value = template_expand_vars(str, &t, state);
+        value = template_getexpr(&t, state->pool);
+        value = template_expand_vars(str, value, state);
     } else
         value = "1";  /* Default unspecified value */
 
@@ -586,7 +565,7 @@ template_expand(char *name, struct template_vals *tvals, struct buffer *b)
     }
     if (!template) {
         str_printf(tvals->error,
-                   "Template %s not found (top level template_expand())",
+                   "Template %s not found (top level template_expand())\n",
                    name);
         err = str_fetch(tvals->error);
         buffer_reset(b);
