@@ -1,4 +1,4 @@
-/* $Cambridge: hermes/src/prayer/servers/prayer.c,v 1.5 2008/10/06 08:45:53 dpc22 Exp $ */
+/* $Cambridge: hermes/src/prayer/servers/prayer.c,v 1.6 2010/07/07 15:02:11 dpc22 Exp $ */
 /************************************************
  *    Prayer - a Webmail Interface              *
  ************************************************/
@@ -156,18 +156,21 @@ BOOL
 prayer_http_port_open(struct prayer * prayer,
                       unsigned long port, BOOL use_ssl, char *interface)
 {
-    int sockfd;
+    int *sockfds, i;
     struct prayer_http_port *fhp;
 
-    if ((sockfd = os_bind_inet_socket(port, interface)) < 0)
+    if (!(sockfds = os_bind_inet_socket(port, interface)))
         return (NIL);
 
-    fhp = pool_alloc(prayer->pool, sizeof(struct prayer_http_port));
-    fhp->port = port;
-    fhp->use_ssl = use_ssl;
-    fhp->sockfd = sockfd;
+    /* Result is list of sockfds, terminated by negative number */
+    for (i=0; sockfds[i] >= 0; i++) {
+        fhp = pool_alloc(prayer->pool, sizeof(struct prayer_http_port));
+        fhp->port = port;
+        fhp->use_ssl = use_ssl;
+        fhp->sockfd = sockfds[i];
 
-    list_push(prayer->http_port_list, (struct list_item *) fhp, NIL);
+        list_push(prayer->http_port_list, (struct list_item *) fhp, NIL);
+    }
     return (T);
 }
 
