@@ -1,4 +1,4 @@
-/* $Cambridge: hermes/src/prayer/session/account.c,v 1.3 2008/09/16 09:59:58 dpc22 Exp $ */
+/* $Cambridge: hermes/src/prayer/session/account.c,v 1.4 2010/07/02 08:31:08 dpc22 Exp $ */
 /************************************************
  *    Prayer - a Webmail Interface              *
  ************************************************/
@@ -35,6 +35,7 @@ struct account *account_create(struct pool *pool, struct session *session)
     result->vacation_enabled = NIL;
     result->vacation_msg = NIL;
     result->vacation_aliases = NIL;
+    result->vacation_subject = NIL;
     result->vacation_days    = 31;
     result->filter_list = list_create(NIL, T);
     result->block_list = list_create(NIL, T);
@@ -71,6 +72,7 @@ void account_free(struct account *account)
 
     string_free((void **) &account->vacation_msg);
     string_free((void **) &account->vacation_aliases);
+    string_free((void **) &account->vacation_subject);
     string_free((void **) &account->spam_whitelist);
 
     if (!account->pool)
@@ -340,12 +342,11 @@ account_mail_check(struct account * account, struct pool * pool)
             return(NIL);
     }
 
-#if 1
     /* XXX Better place for this? */
     if (!(account->vacation_aliases && account->vacation_aliases[0]) &&
         prefs->alt_addr && prefs->alt_addr[0])
         string_strdup(&account->vacation_aliases, prefs->alt_addr);
-#endif
+
     account->mail_checked = T;
 
     return(T);
