@@ -1,4 +1,4 @@
-/* $Cambridge: hermes/src/prayer/session/prefs.c,v 1.2 2008/05/19 15:55:58 dpc22 Exp $ */
+/* $Cambridge: hermes/src/prayer/session/prefs.c,v 1.3 2008/09/16 09:59:58 dpc22 Exp $ */
 /************************************************
  *    Prayer - a Webmail Interface              *
  ************************************************/
@@ -94,9 +94,10 @@ struct prefs *prefs_create(struct config *config)
     struct prefs *p = pool_alloc(pool, sizeof(struct prefs));
 
     p->pool = pool;
-    p->confirm_expunge = config->confirm_expunge;
-    p->confirm_logout  = config->confirm_logout;
-    p->confirm_rm      = config->confirm_rm;
+    p->allow_raven_login = config->allow_raven_login;
+    p->confirm_expunge   = config->confirm_expunge;
+    p->confirm_logout    = config->confirm_logout;
+    p->confirm_rm        = config->confirm_rm;
 
     if (config->msgs_per_page > 0)
         p->msgs_per_page = config->msgs_per_page;
@@ -108,6 +109,8 @@ struct prefs *prefs_create(struct config *config)
     else
         p->abook_per_page = 12;
 
+    p->template_set = config->template_set;
+
     if (config->maildir)
         p->maildir = config->maildir;
     else
@@ -117,7 +120,6 @@ struct prefs *prefs_create(struct config *config)
     p->sent_mail_folder = config->sent_mail_folder;
 
     p->suppress_dotfiles = config->suppress_dotfiles;
-    p->use_full_date = T;
     p->from_personal = "";
     p->from_address = "";
     p->default_reply_to = "";
@@ -172,6 +174,7 @@ struct prefs *prefs_create(struct config *config)
 
     p->use_icons = config->use_icons;
     p->use_welcome = config->use_welcome;
+    p->use_unread = config->use_unread;
     p->use_tail_banner = config->use_tail_banner;
     p->use_mark_persist = config->use_mark_persist;
     p->use_cookie = config->use_cookie;
@@ -179,15 +182,15 @@ struct prefs *prefs_create(struct config *config)
 
     p->use_http_1_1 = config->use_http_1_1;
     p->use_pipelining = config->use_pipelining;
-    p->use_embed_http = config->use_embed_http;
     p->use_persist = config->use_persist;
     p->use_short = config->use_short;
     p->use_gzip = config->use_gzip;
-    p->is_netscape4 = config->is_netscape4;
 
     p->html_inline = config->html_inline;
     p->html_inline_auto = config->html_inline_auto;
+    p->html_remote_images = config->html_remote_images;
     p->preserve_mimetype = config->preserve_mimetype;
+    p->expunge_on_exit = config->expunge_on_exit;
 
     return (p);
 }
@@ -209,11 +212,13 @@ struct prefs *prefs_copy(struct prefs *src)
     struct prefs *dest = pool_alloc(pool, sizeof(struct prefs));
 
     dest->pool = pool;
+    dest->allow_raven_login = src->allow_raven_login;
     dest->confirm_expunge  = src->confirm_expunge;
     dest->confirm_logout   = src->confirm_logout;
     dest->confirm_rm       = src->confirm_rm;
     dest->msgs_per_page    = src->msgs_per_page;
     dest->abook_per_page   = src->abook_per_page;
+    dest->template_set     = pool_strdup(pool, src->template_set);
     dest->maildir = pool_strdup(pool, src->maildir);
     dest->postponed_folder = pool_strdup(pool, src->postponed_folder);
     dest->sent_mail_folder = pool_strdup(pool, src->sent_mail_folder);
@@ -252,21 +257,22 @@ struct prefs *prefs_copy(struct prefs *src)
 
     dest->use_icons = src->use_icons;
     dest->use_welcome = src->use_welcome;
+    dest->use_unread = src->use_unread;
     dest->use_tail_banner = src->use_tail_banner;
     dest->use_mark_persist = src->use_mark_persist;
     dest->use_cookie = src->use_cookie;
     dest->use_substitution = src->use_substitution;
     dest->use_http_1_1 = src->use_http_1_1;
     dest->use_pipelining = src->use_pipelining;
-    dest->use_embed_http = src->use_embed_http;
     dest->use_persist = src->use_persist;
     dest->use_short = src->use_short;
     dest->use_gzip = src->use_gzip;
-    dest->is_netscape4 = src->is_netscape4;
 
     dest->html_inline = src->html_inline;
     dest->html_inline_auto = src->html_inline_auto;
+    dest->html_remote_images = src->html_remote_images;
     dest->preserve_mimetype = src->preserve_mimetype;
+    dest->expunge_on_exit = src->expunge_on_exit;
 
     return (dest);
 }
@@ -298,6 +304,7 @@ void
 prefs_parse_option(struct prefs *prefs, char *line,
                    struct session *session)
 {
+    struct config *config = session->config;
     unsigned long numvalue;
     char *key, *value;
     unsigned long len;
@@ -334,8 +341,11 @@ prefs_parse_option(struct prefs *prefs, char *line,
                 prefs->abook_sort_mode = ABOOK_SORT_EMAIL;
             else
                 prefs->abook_sort_mode = ABOOK_SORT_ORDER;     /* Default */
-        } else if (!strcmp(key, "abook_sort_reverse"))
+        } else if (!strcmp(key, "abook_sort_reverse")) {
             prefs->abook_sort_reverse = options_parse_bool(value);
+        } else if (!strcmp(key, "allow_raven_login")) {
+            prefs->allow_raven_login = options_parse_bool(value);
+        }
         break;
     case 'c':
         if (!strcmp(key, "confirm_expunge"))
@@ -353,18 +363,22 @@ prefs_parse_option(struct prefs *prefs, char *line,
             prefs->default_reply_to
                 = pool_strdup(prefs->pool, options_decode(value));
         break;
+    case 'e':
+        if (!strcmp(key, "expunge_on_exit"))
+            prefs->expunge_on_exit = options_parse_bool(value);
+        break;
     case 'h':
         if (!strcmp(key, "html_inline"))
             prefs->html_inline = options_parse_bool(value);
         else if (!strcmp(key, "html_inline_auto"))
             prefs->html_inline_auto = options_parse_bool(value);
+        else if (!strcmp(key, "html_remote_images"))
+            prefs->html_remote_images = options_parse_bool(value);
         break;
     case 'i':
         if (!strcmp(key, "ispell_language"))
             prefs->ispell_language =
                 pool_strdup(prefs->pool, options_decode(value));
-        else if (!strcmp(key, "is_netscape4"))
-            prefs->is_netscape4 = options_parse_bool(value);
         break;
     case 'f':
         if (!strcmp(key, "from_personal"))
@@ -460,7 +474,13 @@ prefs_parse_option(struct prefs *prefs, char *line,
         }
         break;
     case 't':
-        if (!strcmp(key, "theme_main_name"))
+        if (!strcmp(key, "template_set")) {
+            char *s = pool_strdup(prefs->pool, options_decode(value));
+
+            if (config->template_list &&
+                list_lookup_byname(config->template_list, s))
+                prefs->template_set = s;
+        } else if (!strcmp(key, "theme_main_name"))
             prefs->theme_main_name =
                 pool_strdup(prefs->pool, options_decode(value));
         else if (!strcmp(key, "theme_help_name"))
@@ -471,6 +491,8 @@ prefs_parse_option(struct prefs *prefs, char *line,
             prefs->use_icons = options_parse_bool(value);
         else if (!strcmp(key, "use_welcome"))
             prefs->use_welcome = options_parse_bool(value);
+        else if (!strcmp(key, "use_unread"))
+            prefs->use_unread = options_parse_bool(value);
         else if (!strcmp(key, "use_tail_banner"))
             prefs->use_tail_banner = options_parse_bool(value);
         else if (!strcmp(key, "use_mark_persist"))
@@ -483,8 +505,6 @@ prefs_parse_option(struct prefs *prefs, char *line,
             prefs->use_http_1_1 = options_parse_bool(value);
         else if (!strcmp(key, "use_pipelining"))
             prefs->use_pipelining = options_parse_bool(value);
-        else if (!strcmp(key, "use_embed_http"))
-            prefs->use_embed_http = options_parse_bool(value);
         else if (!strcmp(key, "use_persist"))
             prefs->use_persist = options_parse_bool(value);
         else if (!strcmp(key, "use_short"))
@@ -556,6 +576,8 @@ void
 prefs_print_options(struct prefs *prefs,
                     struct config *config, struct buffer *b)
 {
+    if (prefs->allow_raven_login != config->allow_raven_login)
+        options_print_bool(b, "allow_raven_login", prefs->allow_raven_login);
     if (prefs->confirm_expunge != config->confirm_expunge)
         options_print_bool(b, "confirm_expunge", prefs->confirm_expunge);
     if (prefs->confirm_logout != config->confirm_logout)
@@ -567,6 +589,8 @@ prefs_print_options(struct prefs *prefs,
     if (prefs->abook_per_page != config->abook_per_page)
         options_print_number(b, "abook_per_page", prefs->abook_per_page);
 
+    if (!prefs_compare_strings(prefs->template_set, config->template_set))
+        options_print(b, "template_set", prefs->template_set);
     if (!prefs_compare_strings(prefs->maildir, config->maildir))
         options_print(b, "maildir", prefs->maildir);
     if (!prefs_compare_strings
@@ -628,6 +652,8 @@ prefs_print_options(struct prefs *prefs,
         options_print_bool(b, "use_icons", prefs->use_icons);
     if (prefs->use_welcome != config->use_welcome)
         options_print_bool(b, "use_welcome", prefs->use_welcome);
+    if (prefs->use_unread != config->use_unread)
+        options_print_bool(b, "use_unread", prefs->use_unread);
 
     if (prefs->use_tail_banner != config->use_tail_banner)
         options_print_bool(b, "use_tail_banner", prefs->use_tail_banner);
@@ -643,24 +669,25 @@ prefs_print_options(struct prefs *prefs,
         options_print_bool(b, "use_http_1_1", prefs->use_http_1_1);
     if (prefs->use_pipelining != config->use_pipelining)
         options_print_bool(b, "use_pipelining", prefs->use_pipelining);
-    if (prefs->use_embed_http != config->use_embed_http)
-        options_print_bool(b, "use_embed_http", prefs->use_embed_http);
     if (prefs->use_persist != config->use_persist)
         options_print_bool(b, "use_persist", prefs->use_persist);
     if (prefs->use_short != config->use_short)
         options_print_bool(b, "use_short", prefs->use_short);
     if (prefs->use_gzip != config->use_gzip)
         options_print_bool(b, "use_gzip", prefs->use_gzip);
-    if (prefs->is_netscape4 != config->is_netscape4)
-        options_print_bool(b, "is_netscape4", prefs->is_netscape4);
 
     if (prefs->html_inline != config->html_inline)
         options_print_bool(b, "html_inline", prefs->html_inline);
     if (prefs->html_inline_auto != config->html_inline_auto)
         options_print_bool(b, "html_inline_auto", prefs->html_inline_auto);
+    if (prefs->html_remote_images != config->html_remote_images)
+        options_print_bool(b, "html_remote_images", prefs->html_remote_images);
     if (prefs->preserve_mimetype != config->preserve_mimetype)
         options_print_bool(b, "preserve_mimetype",
                            prefs->preserve_mimetype);
+    if (prefs->expunge_on_exit != config->expunge_on_exit)
+        options_print_bool(b, "expunge_on_exit",
+                           prefs->expunge_on_exit);
 
     if (prefs->sort_mode != prefs_sort_mode(config->sort_mode)) {
         if (prefs->sort_mode == DATE)
