@@ -1,4 +1,4 @@
-/* $Cambridge: hermes/src/prayer/session/rfc1522.c,v 1.3 2008/09/16 09:59:58 dpc22 Exp $ */
+/* $Cambridge: hermes/src/prayer/session/rfc1522.c,v 1.4 2011/06/22 09:50:18 dpc22 Exp $ */
 /************************************************
  *    Prayer - a Webmail Interface              *
  ************************************************/
@@ -492,17 +492,66 @@ char *charset;
  * rfc1522_encoded_word -- cut given string into max length encoded word
  *
  * Return: pointer into 's' such that the encoded 's' is no greater
- *	   than RFC1522_MAXW
- *
- *  NOTE: this line break code is NOT cognizant of any SI/SO
- *  charset requirements nor similar strategies using escape
- *  codes.  Hopefully this will matter little and such
- *  representation strategies don't also include 8bit chars.
+ *	   than RFC1522_MAXW. Important that we don't break
+ *         multibyte UTF-8 characters in the middle.
  */
-unsigned char *rfc1522_encoded_word(s, enc, charset)
-unsigned char *s;
-int enc;
-char *charset;
+
+/* Couple of support functions first */
+static int utf8_char_len(unsigned char c)
+{
+    if      ( ((c) & 0xFE) == 0xFC ) return(6);
+    else if ( ((c) & 0xFC) == 0xF8 ) return(5);
+    else if ( ((c) & 0xF8) == 0xF0 ) return(4);
+    else if ( ((c) & 0xF0) == 0xE0 ) return(3);
+    else if ( ((c) & 0xE0) == 0xC0 ) return(2);
+
+    return(1);
+}
+
+static unsigned char *
+rfc1522_encoded_word_utf8(unsigned char *s,
+                          int enc,
+                          char *charset)
+{
+    int goal = RFC1522_MAXW - RFC1522_OVERHEAD(charset);  /* always >60 */
+
+    if (enc == 'B') {            /* base64 encode */
+        goal = ((goal / 4) * 3) - 2;
+        while (*s && (goal > 0)) {
+            int len = utf8_char_len(*s);
+
+            goal-=len;
+            /* Does this UTF-8 character fit on current line? */
+            if (goal >= 0) {    
+                while (*s && (len > 0)) {
+                    s++;
+                    len--;
+                }
+            }
+        }
+    } else {                       /* special 'Q' encoding */
+        while (*s && (goal > 0)) {
+            int len = utf8_char_len(*s);
+            unsigned char *t = s;
+
+            while (*t && (len > 0)) {
+                goal -= RFC1522_ENC_CHAR(*t) ? 3 : 1;
+                t++;
+                len--;
+            }
+            /* Does this UTF-8 character fit on current line? */
+            if (goal >= 0)          
+                s = t;
+        }
+    }
+
+    return (s);
+}
+
+static unsigned char *
+rfc1522_encoded_word_simple(unsigned char *s,
+                            int enc,
+                            char *charset)
 {
     int goal = RFC1522_MAXW - RFC1522_OVERHEAD(charset);
 
@@ -516,7 +565,16 @@ char *charset;
     return (s);
 }
 
-
+unsigned char *rfc1522_encoded_word(s, enc, charset)
+unsigned char *s;
+int enc;
+char *charset;
+{
+    if (!strcasecmp(charset, "UTF-8"))
+        return(rfc1522_encoded_word_utf8(s, enc, charset));
+    else
+        return(rfc1522_encoded_word_simple(s, enc, charset));
+}
 
 /*
  * rfc1522_8bit -- apply RFC 1522 'Q' encoding to the given 8bit buffer
