@@ -1,4 +1,4 @@
-/* $Cambridge: hermes/src/prayer/session/session.c,v 1.10 2009/08/28 15:13:11 dpc22 Exp $ */
+/* $Cambridge: hermes/src/prayer/session/session.c,v 1.11 2010/07/02 14:32:06 dpc22 Exp $ */
 /************************************************
  *    Prayer - a Webmail Interface              *
  ************************************************/
@@ -500,6 +500,7 @@ void session_setup_urls(struct session *session)
     struct pool *p = session->pool;
     char *icon_opts;
     char *quoted_user;
+    unsigned long pid = (unsigned long)getpid();
 
     if (user_agent->manual) {
         struct buffer *b = buffer_create(p, 128);
@@ -555,24 +556,24 @@ void session_setup_urls(struct session *session)
     if (session->use_ssl) {
         if (session->session_port == 443)
             session->url_prefix_asession
-                = pool_printf(p, "https://%s/session/%s",
-                              config->hostname, quoted_user);
+                = pool_printf(p, "https://%s/session/%s:%lu",
+                              config->hostname, quoted_user, pid);
         else
             session->url_prefix_asession
                 =
-                pool_printf(p, "https://%s:%d/session/%s",
+                pool_printf(p, "https://%s:%d/session/%s:%lu",
                             config->hostname, session->session_port,
-                            quoted_user);
+                            quoted_user, pid);
     } else {
         if (session->session_port == 80)
             session->url_prefix_asession
-                = pool_printf(p, "http://%s/session/%s",
-                              config->hostname, quoted_user);
+                = pool_printf(p, "http://%s/session/%s:%lu",
+                              config->hostname, quoted_user, pid);
         else
             session->url_prefix_asession
                 =
-                pool_printf(p, "http://%s:%d/session/%s", config->hostname,
-                            session->session_port, quoted_user);
+                pool_printf(p, "http://%s:%d/session/%s:%lu", config->hostname,
+                            session->session_port, quoted_user, pid);
     }
 
     /* Calculate url_prefix_bsession and url_bsession              */
@@ -1137,64 +1138,6 @@ session_make_redirect(struct session *session,
     response_redirect(request, url);
 }
 
-/* session_make_cookie_redirect() ****************************************
- *
- * Generate HTTP redirect relative to URL prefix. Send a session cookie
- * (username=sessionid) or (username:port=sessionid) at the same time.
- *   session:
- *   request: Current HTTP request
- *  location: Target for redirect.
- ************************************************************************/
-
-void
-session_make_cookie_redirect(struct session *session,
-                             struct request *request, char *location)
-{
-    struct config *config = session->config;
-    char *url = pool_strcat(request->pool, session->url_prefix, location);
-    char *path =
-        pool_strcat(request->pool, "/session/", session->username);
-    char *key;
-
-    if (config->http_cookie_use_port)
-        key = pool_printf(request->pool, "%s:%lu",
-                          session->username, session->session_port);
-    else
-        key = session->username;
-
-    response_cookie_redirect(request, url, key, session->sessionid,
-			     path, config->hostname, session->use_ssl);
-}
-
-/* session_make_clear_cookie_redirect() **********************************
- *
- * Generate HTTP redirect relative to URL prefix. Clears session cookie
- * (username=sessionid) or (username:port=sessionid) at the same time.
- *   session:
- *   request: Current HTTP request
- *  location: Target for redirect.
- ************************************************************************/
-
-void
-session_make_clear_cookie_redirect(struct session *session,
-                                   struct request *request, char *location)
-{
-    struct config *config = session->config;
-    char *url = pool_strcat(request->pool, session->url_prefix, location);
-    char *path =
-        pool_strcat(request->pool, "/session/", session->username);
-    char *key;
-
-    if (config->http_cookie_use_port)
-        key = pool_printf(request->pool, "%s:%lu",
-                          session->username, session->session_port);
-    else
-        key = session->username;
-
-    response_clear_cookie_redirect(request, url, key, session->sessionid,
-                                   path, config->hostname, session->use_ssl);
-}
-
 /* ====================================================================== */
 
 /* session_make_session_redirect() ***************************************
@@ -1244,8 +1187,9 @@ session_make_session_cookie_redirect(struct session *session,
     struct config *config = session->config;
     char *url =
         pool_strcat3(request->pool, session->url_prefix_session, "/", cmd);
-    char *path =
-        pool_strcat(request->pool, "/session/", session->username);
+    unsigned long pid = (unsigned long)getpid();
+    char *path = pool_printf(request->pool,
+                             "/session/%s:%lu", session->username, pid);
     char *key;
 
     if (session->use_short) {
@@ -1259,11 +1203,7 @@ session_make_session_cookie_redirect(struct session *session,
         }
     }
 
-    if (config->http_cookie_use_port)
-        key = pool_printf(request->pool, "%s:%lu",
-                          session->username, session->session_port);
-    else
-        key = session->username;
+    key = pool_printf(request->pool, "%s:%lu", session->username, pid);
 
     response_cookie_redirect(request, url, key, session->sessionid,
 			     path, config->hostname, session->use_ssl);
@@ -1284,17 +1224,14 @@ session_make_session_clear_cookie_redirect(struct session *session,
                                            char *cmd)
 {
     struct config *config = session->config;
+    unsigned long pid = (unsigned long)getpid();
     char *url =
         pool_strcat3(request->pool, session->url_prefix_session, "/", cmd);
-    char *path =
-        pool_strcat(request->pool, "/session/", session->username);
+    char *path = pool_printf(request->pool,
+                             "/session/%s:%lu", session->username, pid);
     char *key;
 
-    if (config->http_cookie_use_port)
-        key = pool_printf(request->pool, "%s:%lu",
-                          session->username, session->session_port);
-    else
-        key = session->username;
+    key = pool_printf(request->pool, "%s:%lu", session->username, pid);
 
     response_clear_cookie_redirect(request, url, key, session->sessionid,
                                    path, config->hostname, session->use_ssl);
