@@ -1,4 +1,4 @@
-/* $Cambridge: hermes/src/prayer/shared/config.c,v 1.9 2008/10/30 11:28:59 dpc22 Exp $ */
+/* $Cambridge: hermes/src/prayer/shared/config.c,v 1.10 2009/10/16 15:03:00 dpc22 Exp $ */
 /************************************************
  *    Prayer - a Webmail Interface              *
  ************************************************/
@@ -167,7 +167,7 @@ struct config *config_create(void)
     config->fatal_dump_core = NIL;
 
     config->template_path = "../templates";
-    config->template_set  = "xhtml_strict";
+    config->template_set  = "old";
     config->template_use_compiled = T;
     config->template_list = NIL;
 
